@@ -6,12 +6,10 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use hex_fmt::HexFmt;
 use serde::{Deserialize, Serialize};
-use std::fmt::{self, Debug, Formatter};
 
 /// Signature created when a quorum of the section elders has agreed on something.
-#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
+#[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
 pub struct KeyedSig {
     /// The BLS public key.
     pub public_key: bls::PublicKey,
@@ -19,17 +17,6 @@ pub struct KeyedSig {
     pub signature: bls::Signature,
 }
 
-impl Debug for KeyedSig {
-    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-        write!(
-            f,
-            "KeyedSig {{ public_key: {:10?}, signature: {:10?} }}",
-            HexFmt(self.public_key.to_bytes()),
-            HexFmt(self.signature.to_bytes())
-        )
-    }
-}
-
 impl KeyedSig {
     /// Verifies this signature against the payload.
     pub fn verify(&self, payload: &[u8]) -> bool {
@@ -38,7 +25,7 @@ impl KeyedSig {
 }
 
 /// Single share of `KeyedSig`.
-#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
+#[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
 pub struct SigShare {
     /// BLS public key set.
     pub public_key_set: bls::PublicKeySet,
@@ -71,17 +58,6 @@ impl SigShare {
     }
 }
 
-impl Debug for SigShare {
-    fn fmt(&self, formatter: &mut Formatter) -> fmt::Result {
-        write!(
-            formatter,
-            "SigShare {{ public_key: {:?}, index: {}, .. }}",
-            self.public_key_set.public_key(),
-            self.index
-        )
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
