@@ -10,7 +10,7 @@ use crate::btree_set;
 use crate::messaging::{
     data::{ChunkDataExchange, ChunkRead, ChunkWrite, CmdError, QueryResponse},
     node::{NodeCmd, NodeMsg, NodeQuery, NodeSystemCmd},
-    ClientSigned, EndUser, MessageId,
+    ClientAuthority, EndUser, MessageId,
 };
 use crate::node::{
     capacity::{Capacity, CHUNK_COPY_COUNT},
@@ -73,13 +73,13 @@ impl ChunkRecords {
         &self,
         write: ChunkWrite,
         msg_id: MessageId,
-        client_signed: ClientSigned,
+        client_auth: ClientAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
         use ChunkWrite::*;
         match write {
-            New(data) => self.store(data, msg_id, client_signed, origin).await,
-            DeletePrivate(address) => self.delete(address, client_signed, origin).await,
+            New(data) => self.store(data, msg_id, client_auth, origin).await,
+            DeletePrivate(address) => self.delete(address, client_auth, origin).await,
         }
     }
 
@@ -108,10 +108,10 @@ impl ChunkRecords {
         &self,
         chunk: Chunk,
         msg_id: MessageId,
-        client_signed: ClientSigned,
+        client_auth: ClientAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
-        if let Err(error) = validate_chunk_owner(&chunk, &client_signed.public_key) {
+        if let Err(error) = validate_chunk_owner(&chunk, client_auth.public_key()) {
             return self.send_error(error, msg_id, origin).await;
         }
 
@@ -133,7 +133,7 @@ impl ChunkRecords {
             msg_id: MessageId::new(),
             msg: NodeMsg::NodeCmd(NodeCmd::Chunks {
                 cmd: ChunkWrite::New(chunk),
-                client_signed,
+                client_signed: client_auth.into(),
                 origin,
             }),
             targets: target_holders,
@@ -215,7 +215,7 @@ impl ChunkRecords {
     async fn delete(
         &self,
         address: ChunkAddress,
-        client_signed: ClientSigned,
+        client_auth: ClientAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
         let targets = self.capacity.get_chunk_holder_adults(address.name()).await;
@@ -224,7 +224,7 @@ impl ChunkRecords {
             msg_id: MessageId::new(),
             msg: NodeMsg::NodeCmd(NodeCmd::Chunks {
                 cmd: ChunkWrite::DeletePrivate(address),
-                client_signed,
+                client_signed: client_auth.into(),
                 origin,
             }),
             targets,
